@@ -463,6 +463,7 @@ typedef struct {
     Boolean testLegality;
     int borderXoffset; /* xboard only */
     int borderYoffset; /* xboard only */
+    Boolean topLevel;  /* xboard, top-level auxiliary windows */
     Boolean titleInWindow; /* xboard only */
     Boolean localLineEditing; /* WinBoard only */
     Boolean zippyTalk;
@@ -654,6 +655,7 @@ typedef struct {
     char *fenOverride[ENGINES];
     char *features[ENGINES];
     char *featureDefaults;
+    char *sysOpen;
     Boolean keepAlive;  /* [HGM] alive     */
     Boolean forceIllegal;/*[HGM] illegal   */
     Boolean noJoin;     /* [HGM] join      */
